<?php
/**
 * TP Philosophy Pro our story customizer options
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

/**
 * Add mission section
 * 
 */

// Add mission section
$wp_customize->add_section( 'tp_philosophy_pro_story_template_mission_section', array(
	'title'             => esc_html__( 'Mission Section','tp-philosophy-pro' ),
	'description'       => esc_html__( 'Mission section options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_our_story_template_panel'
) );


// Add enable services setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_enable]', array(
	'default'           => $options['story_template_mission_enable'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_mission_enable]', array(
	'label'             => esc_html__( 'Enable Mission section', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_story_template_mission_section',
	'type'              => 'checkbox',
) );

// Add service section name.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_section_title]', array(
	'default'           => $options['story_template_mission_section_title'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_mission_section_title]', array(
	'label'             => esc_html__( 'Enter Section Title', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_story_template_mission_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_story_template_mission_enabled',
) );

// Add our services heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_left_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[story_template_mission_left_heading]', array(
	'label'           	=> esc_html__( 'Left section options', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_story_template_mission_section',
	'type'				=> 'description',
	'active_callback' 	=> 'tp_philosophy_pro_is_story_template_mission_enabled',
) ) );


// Add custom title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_title]',
	array(
		'sanitize_callback'		=> 'tp_philosophy_pro_story_template_santize_allow_tag',
		'default' 				=> $options['story_template_mission_title'],
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_mission_title]',
    array(
		'label'      			=> esc_html__( 'Title', 'tp-philosophy-pro' ),
		'description'			=> sprintf( 'Only &lt;span class=&ldquo; sub-title &rdquo; &gt; tag is allowed', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_story_template_mission_section',
        'active_callback'		=> 'tp_philosophy_pro_is_story_template_mission_enabled',
    )
);

// Add custom description
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_description]',
	array(
		'sanitize_callback'		=> 'wp_kses_data',
		'default' 				=> $options['story_template_mission_description'],
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_mission_description]',
    array(
		'label'      			=> esc_html__( 'Description', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_story_template_mission_section',
		'type'					=> 'textarea',
        'active_callback'		=> 'tp_philosophy_pro_is_story_template_mission_enabled',
    )
);

/**
 * 
 * Right section
 *
 * @since 1.0
 */

// Add our services heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_right_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[story_template_mission_right_heading]', array(
	'label'           	=> esc_html__( 'Right section options', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_story_template_mission_section',
	'type'				=> 'description',
	'active_callback' 	=> 'tp_philosophy_pro_is_story_template_mission_enabled',
) ) );

$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_content_type]', array(
	'default'           	=> $options['story_template_mission_content_type'],
	'sanitize_callback' 	=> 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_mission_content_type]', array(
	'label'             	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'description'           => esc_html__( 'Select content type.', 'tp-philosophy-pro' ),
	'section'           	=> 'tp_philosophy_pro_story_template_mission_section',
	'type'             	 	=> 'select',
	'choices'			  	=> array( 
		'post' => esc_html__( 'Post', 'tp-philosophy-pro' ),
		'page' => esc_html__( 'Page', 'tp-philosophy-pro' ),
	),
	'active_callback'		=> 'tp_philosophy_pro_is_story_template_mission_enabled'
) );

for ( $i=1; $i <=4 ; $i++) {
	// Add setting and controls to input page id
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_page_id_' . $i . ']', array(
		'sanitize_callback' => 'tp_philosophy_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_mission_page_id_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page # ' , 'tp-philosophy-pro' ) . $i ),
		'section'           => 'tp_philosophy_pro_story_template_mission_section',
		'type'              => 'dropdown-pages',
		'active_callback'	=> 'tp_philosophy_pro_is_story_template_mission_page_enabled',
	) ); 
}

// Add setting and controls to input post id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_mission_posts_ids]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_mission_posts_ids]', array(
	'label'           => esc_html__( 'Enter Post ID', 'tp-philosophy-pro' ),
	'description' 	  => esc_html__( 'Enter post ID seperated with comma. Max post ids allowed is 4. Example 88,91,93', 'tp-philosophy-pro' ),
	'section'         => 'tp_philosophy_pro_story_template_mission_section',
	'active_callback' => 'tp_philosophy_pro_is_story_template_mission_post_enabled',
) );

/**
 *
 * Service section
 *
 * @since 1.0
 *
 */

$description = esc_html__( 'For icons visit ', 'tp-philosophy-pro' ) . sprintf( '<a target="_blank" href="' . esc_url( 'http://fontawesome.io/icons/' ) . '"> %s </a>', esc_html__( 'Font awesome', 'tp-philosophy-pro' ) );

// Add our story template section
$wp_customize->add_section( 'tp_philosophy_pro_story_template_service_section', array(
	'title'             => esc_html__( 'Service Section','tp-philosophy-pro' ),
	'description'       => $description,
	'panel'             => 'tp_philosophy_pro_our_story_template_panel'
) );

// Add our services heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_services_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[story_template_services_heading]', array(
	'label'           	=> esc_html__( 'Our Services Options', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_story_template_service_section',
	'type'				=> 'description',
) ) );

// Add enable services setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_services_enable]', array(
	'default'           => $options['story_template_services_enable'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_services_enable]', array(
	'label'             => esc_html__( 'Enable Services', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_story_template_service_section',
	'type'              => 'checkbox',
) );

// Add service section name.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_service_section_title]', array(
	'default'           => $options['story_template_service_section_title'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_service_section_title]', array(
	'label'             => esc_html__( 'Enter Section Title', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_story_template_service_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_story_template_service_enabled',
) );

// Add custom image setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_service_section_image]', array(
	'default'           => $options['story_template_service_section_image'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'tp_philosophy_pro_theme_options[story_template_service_section_image]',
    array(
		'label'           => esc_html__( 'Upload Background Image', 'tp-philosophy-pro' ),
		'description'     => esc_html__( 'Recommended slide image size is 1920x1290 px', 'tp-philosophy-pro' ),
		'section'         => 'tp_philosophy_pro_story_template_service_section',
		'active_callback' => 'tp_philosophy_pro_is_story_template_service_enabled',
   )
) );

// Add column layout option.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_column_layout]', array(
	'default'           	=> $options['story_template_column_layout'],
	'sanitize_callback' 	=> 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_column_layout]', array(
	'label'             	=> esc_html__( 'Column Layout', 'tp-philosophy-pro' ),
	'description'           => esc_html__( 'Save and then refresh page to view changes.', 'tp-philosophy-pro' ),
	'section'           	=> 'tp_philosophy_pro_story_template_service_section',
	'type'             	 	=> 'select',
	'choices'			  	=> array( 
		'3' => esc_html__( '3-Column', 'tp-philosophy-pro' ),
		'4' => esc_html__( '4-Column', 'tp-philosophy-pro' ),
		'5' => esc_html__( '5-Column', 'tp-philosophy-pro' ),
	),
	'active_callback'		=> 'tp_philosophy_pro_is_story_template_service_enabled'
) );

$column_layout =  $options['story_template_column_layout'];

for ( $i=1; $i <= absint( $column_layout ); $i++ ) { 
	// Add service icon setting and control.
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_service_icon_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_service_icon_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Service Icon # %1$s', 'tp-philosophy-pro' ), $i ),
		'input_attrs'		=> array( 
			'placeholder' 	=> esc_attr( 'fa-glass', 'tp-philosophy-pro' ),
		),
		'section'           => 'tp_philosophy_pro_story_template_service_section',

		'active_callback' 	=> 'tp_philosophy_pro_is_story_template_service_enabled',
	) );

	// Add service text setting and control.
	$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_service_text_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_service_text_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Service Text # %1$s', 'tp-philosophy-pro' ), $i ),
		'section'           => 'tp_philosophy_pro_story_template_service_section',
		'active_callback' 	=> 'tp_philosophy_pro_is_story_template_service_enabled',
	) );
}

/**
 *
 * Quote section
 *
 * @since 1.0
 *
 */

// Add our story template section
$wp_customize->add_section( 'tp_philosophy_pro_story_template_quote_section', array(
	'title'             => esc_html__( 'Quote Section','tp-philosophy-pro' ),
	'description'       => esc_html__( 'Quote section options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_our_story_template_panel'
) );

// Add quote heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_quote_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[story_template_quote_heading]', array(
	'label'           	=> esc_html__( 'Quote Options', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_story_template_quote_section',
	'type'				=> 'description',
) ) );

// Add enable quote setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_quote_enable]', array(
	'default'           => $options['story_template_quote_enable'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_quote_enable]', array(
	'label'             => esc_html__( 'Enable Quote', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_story_template_quote_section',
	'type'              => 'checkbox',
) );

// Add quote section title.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_quote_section_title]', array(
	'default'           => $options['story_template_quote_section_title'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_quote_section_title]', array(
	'label'             => esc_html__( 'Enter Section Title', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_story_template_quote_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_story_template_quote_enabled',
) );

// Add custom title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_quote_title]',
	array(
		'sanitize_callback'		=> 'tp_philosophy_pro_story_template_quote_allow_tag',
		'default' 				=> $options['story_template_quote_title'],
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_quote_title]',
    array(
		'label'      			=> esc_html__( 'Title', 'tp-philosophy-pro' ),
		'description' 			=> esc_html__( '&lt;h1 class=&ldquo;entry-title&rdquo; &gt; and &lt;h2 class=&ldquo;sub-title&rdquo; &gt; tags are allowed.', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_story_template_quote_section',
		'type' 					=> 'textarea',
        'active_callback'		=> 'tp_philosophy_pro_is_story_template_quote_enabled',
    )
);

// Add quote option
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_quote_text]',
	array(
		'sanitize_callback'		=> 'tp_philosophy_pro_works_quote_santize_allow_tag',
		'option' 				=> $options['story_template_quote_text'],
	)
);
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_quote_text]',
    array(
		'label'      			=> esc_html__( 'Quote text', 'tp-philosophy-pro' ),
		'description'			=> esc_html__( 'Input blogquotes. Only &lt;blogquotes&gt; and &lt;a&gt; tags are allowed.', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_story_template_quote_section',
		'type'		 			=> 'textarea',
		'input_attrs' 			=> array(
			'placeholder' 	=> sprintf( '<blockquote>&quot; %1$s &quot;</blockquote>
                  <a href="#" class="worker-name">%2$s</a>', esc_html__( 'The Business Bio-graphy team refined our brand, and designed a web site that we&rsquo;re proud of.', 'tp-philosophy-pro' ), esc_html__( '-Sandeep Regmi, Themepalace.com', 'tp-philosophy-pro' ) ),
		),
        'active_callback'		=> 'tp_philosophy_pro_is_story_template_quote_enabled',
    )
);

/**
 *
 * Team section
 *
 * @since 1.0
 */

// Add our teams  section
$wp_customize->add_section( 'tp_philosophy_pro_story_template_team_section', array(
	'title'             => esc_html__( 'Teams Section','tp-philosophy-pro' ),
	'description'       => esc_html__( 'Story template team options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_our_story_template_panel'
) );


// Add our teams option heading setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_team_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[story_template_team_heading]', array(
	'label'           	=> esc_html__( 'Team Options', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_story_template_team_section',
	'type'				=> 'description',
) ) );

// Add enable team options setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_team_enable]', array(
	'default'           => $options['story_template_team_enable'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_team_enable]', array(
	'label'             => esc_html__( 'Enable Teams Options.', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_story_template_team_section',
	'type'              => 'checkbox',
) );

// Add team section title.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_team_section_title]', array(
	'default'           => $options['story_template_team_section_title'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_team_section_title]', array(
	'label'             => esc_html__( 'Enter Section Title', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_story_template_team_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_story_template_team_enabled',
) );


// Add team custom title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_work_title]',
	array(
		'sanitize_callback'		=> 'tp_philosophy_pro_story_template_quote_allow_tag',
		'default' 				=> $options['story_template_work_title'],
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_work_title]',
    array(
		'label'      			=> esc_html__( 'Title', 'tp-philosophy-pro' ),
		'description' 			=> esc_html__( '&lt;h1 class=&ldquo;entry-title&rdquo; &gt; and &lt;h2 class=&ldquo;sub-title&rdquo; &gt; tags are allowed.', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_story_template_team_section',
		'type' 					=> 'textarea',
        'active_callback'		=> 'tp_philosophy_pro_is_story_template_team_enabled',
    )
);

// Add team custom description
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_work_description]',
	array(
		'default' 				=> $options['story_template_work_description'],
		'sanitize_callback'		=> 'wp_kses_data',
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_work_description]',
    array(
		'label'      			=> esc_html__( 'Description', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_story_template_team_section',
		'type'					=> 'textarea',
        'active_callback'		=> 'tp_philosophy_pro_is_story_template_team_enabled',
    )
);

// Add team options content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_team_content_type]', array(
	'default'           => $options['story_template_team_content_type'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

if ( ! class_exists( 'TP_Philosophy_Tools' ) ) {
    $content_type_description = esc_html__( 'Team Option requires', 'tp-philosophy-pro' ) . sprintf( '<a target="_blank" href="%s"> %s </a>', esc_url( 'https://wordpress.org/plugins/tp-philosophy-teams/' ), esc_html__( 'TP Philosophy Tools Plugin', 'tp-philosophy-pro' ) );

	$choices = array(
		'post'            => esc_html__( 'Default Posts', 'tp-philosophy-pro' ),
	);
} else{
    $content_type_description = '';
    $choices = array(
		'post'            => esc_html__( 'Default Posts', 'tp-philosophy-pro' ),
		'tp-philosophy-teams' => esc_html__( 'Plugin Team Posts.', 'tp-philosophy-pro' ),
	);
}
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_team_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'description' 		=> $content_type_description,
	'section'         	=> 'tp_philosophy_pro_story_template_team_section',
	'type'            	=> 'select',
	'active_callback' 		=> 'tp_philosophy_pro_is_story_template_team_enabled',	
	'choices'         	=> $choices
) );

// Add setting and controls to input post id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_team_default_posts_ids]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_team_default_posts_ids]', array(
	'label'           => esc_html__( 'Enter Post IDs', 'tp-philosophy-pro' ),
	'description' 	  => esc_html__( 'Enter default post ID seperated with comma. Max post ids allowed is 3. Example 88,91,93', 'tp-philosophy-pro' ),
	'section'         => 'tp_philosophy_pro_story_template_team_section',
	'active_callback' => 'tp_philosophy_pro_is_story_template_team_default_post_enabled',
) );

// Add setting and controls to input post id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_team_plugin_posts_ids]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_team_plugin_posts_ids]', array(
	'label'           => esc_html__( 'Enter Team Post IDs', 'tp-philosophy-pro' ),
	'description' 	  => esc_html__( 'Enter plugin post ID seperated with comma. Example 51,53,55', 'tp-philosophy-pro' ),
	'section'         => 'tp_philosophy_pro_story_template_team_section',
	'active_callback' => 'tp_philosophy_pro_is_story_template_plugin_team_post_enabled',
) );

// Add learn more text setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_team_view_more_text]', array(
	'default'           => $options['story_template_team_view_more_text'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_team_view_more_text]', array(
	'label'           	=> esc_html__( 'View More Text', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Leave empty to hide button', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_story_template_team_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_story_template_team_enabled',
) );

// Add slider link setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[story_template_view_teams_link]', array(
	'default'           => $options['story_template_view_teams_link'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[story_template_view_teams_link]', array(
	'label'           	=> esc_html__( 'Link', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Input link', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_story_template_team_section',
	'type'				=> 'url',
	'active_callback' 	=> 'tp_philosophy_pro_is_story_template_team_enabled',
) );