<?php
/**
 * Services section
 *
 * This is the template for the content of services section
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

if ( ! function_exists( 'tp_philosophy_pro_add_services_section' ) ) :
    /**
     * Add services section
     *
     * @since 1.0
     */
    function tp_philosophy_pro_add_services_section() {
        // Check if services section is enabled on frontpage
        $services_section_enable = apply_filters( 'tp_philosophy_pro_section_status', true, 'services_enable' );
        if ( true !== $services_section_enable ) {
            return false;
        }

        $options = tp_philosophy_pro_get_theme_options(); // Get theme options
        $service_content_type = $options['services_left_content_type'];

        if ( 'demo' == $service_content_type ) {
            $services_inline_css = "style='background-image: url(". get_template_directory_uri() . '/assets/uploads/services.jpg' .");'";
        } else{
            $background_image = ! empty( $options['services_custom_image'] ) ? $options['services_custom_image'] : '';
            if( !empty( $background_image ) ){
                $services_inline_css = "style='background-image: url(".esc_url( $background_image ) .");'";
            } else {
                $services_inline_css = '';
            } 
        }
        ?> 

        <section id="services" class="col-2 page-section services" <?php echo ( $services_inline_css ); ?>>
            <div class="wrapper">
                <div class="black-overlay"></div>
                <div class="row">
                <?php
                    /**
                     * tp_philosophy_pro_services_left_content hook
                     *
                     * @hooked tp_philosophy_pro_get_services_left_content -  10
                     */
                    do_action( 'tp_philosophy_pro_services_left_content' );

                    /**
                     * tp_philosophy_pro_services_right_content hook
                     *
                     * @hooked tp_philosophy_pro_get_services_right_content -  10
                     */
                    do_action( 'tp_philosophy_pro_services_right_content' );
                ?>
                </div><!-- .row -->
            </div><!-- .wrapper -->
        </section><!-- #services -->
        <?php
    }
endif;
add_action( 'tp_philosophy_pro_homepage_section', 'tp_philosophy_pro_add_services_section', 30 );

if ( ! function_exists( 'tp_philosophy_pro_get_services_left_content' ) ) : 
    /**
     * Add services section left content
     *
     * @since 1.0
     */
    function tp_philosophy_pro_get_services_left_content() {
        // Get services section details
        $section_details = array();
        $section_details = apply_filters( 'tp_philosophy_pro_filter_services_left_details', $section_details );
        if ( empty( $section_details ) ) {
          return;
        }

        // Render services section now.
        tp_philosophy_pro_render_services_left_section( $section_details );
    }
endif;
add_action( 'tp_philosophy_pro_services_left_content', 'tp_philosophy_pro_get_services_left_content', 10 );

if ( ! function_exists( 'tp_philosophy_pro_get_services_left_section_details' ) ) :
  /**
   * Services section details.
   *
   * @since 1.0
   * @param array $input services left section details.
   */
  function tp_philosophy_pro_get_services_left_section_details( $input ) {
    $options = tp_philosophy_pro_get_theme_options();

    // services section options
    $services_left_content_type     = $options['services_left_content_type'];
    $services_subtitle         = !empty( $options['services_subtitle'] ) ? $options['services_subtitle'] : '';
    $read_more_text            = !empty( $options['services_learn_more_text'] ) ? $options['services_learn_more_text'] : esc_html__( 'View Services', 'tp-philosophy-pro' );

    $content = array();
    switch ( $services_left_content_type ) {
        case 'demo':
            $content['title']               = esc_html__( 'Service', 'tp-philosophy-pro' );
            $content['subtitle']            = esc_html__( 'BEST WE OFFER.', 'tp-philosophy-pro' );
            $content['description']         = esc_html__( 'Sed congue cursus quam quis fermentum. Nullam augue risus, molestie non est non, elementum tristique ex. Fusce vel magna est. Praesent in eleifend nulla, et sagittis leo. Nunc feugiat semper tellus. Cras justo sapien, imperdiet eu fringilla eu, accumsan a sem. Nullam lacinia arcu sed massa auctor, vel efficitur diam sollicitudin.', 'tp-philosophy-pro' );
            
            $content['read_more_text']      = esc_html__( 'View Services', 'tp-philosophy-pro' );
            $content['read_more_link']      = '#';
        break;

        case 'posts':
            $post_id = !empty ( $options['services_post_id'] ) ? absint( $options['services_post_id'] ) : '';

            if( empty( $post_id  ) ) return $input; // Return if post id is empty

            $service_post = get_post( $post_id ); // Get service post
            
            $content['title']               = get_the_title( $service_post->ID );
            $content['subtitle']            = $services_subtitle;
            $content['description']         = tp_philosophy_pro_trim_content( 55, $service_post );
            
            $content['read_more_text']      = $read_more_text;
            $content['read_more_link']      = get_the_permalink( $service_post->ID );
        break;
        
        case 'pages':
            $page_id = !empty ( $options['services_page_id'] ) ? absint( $options['services_page_id'] ) : '';

            if( empty( $page_id  ) ) return $input; // Return if post id is empty

            $service_page = get_post( $page_id ); // Get service post

            $content['title']               = get_the_title( $service_page->ID );
            $content['subtitle']            = $services_subtitle;
            $content['description']         = tp_philosophy_pro_trim_content( 55, $service_page );
            
            $content['read_more_text']      = $read_more_text;
            $content['read_more_link']      = get_the_permalink( $service_page->ID );
        break;

        case 'custom':
            $content['title']               = !empty( $options['services_custom_title'] ) ? $options['services_custom_title'] : '';
            $content['subtitle']            = $services_subtitle;
            $content['description']         = !empty( $options['services_custom_description'] ) ? $options['services_custom_description'] : '';
            
            $content['read_more_text']      = $read_more_text;
            $content['read_more_link']      = !empty( $options['services_custom_link'] ) ? $options['services_custom_link'] :'#';
        break;

        default:
        break;
    }
                                                                                                               
    if ( !empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// services section content details.
add_filter( 'tp_philosophy_pro_filter_services_left_details', 'tp_philosophy_pro_get_services_left_section_details' );

if ( ! function_exists( 'tp_philosophy_pro_render_services_left_section' ) ) :
  /**
   * Start services left section
   *
   * @return string services left section content
   * @since 1.0
   *
   */
   function tp_philosophy_pro_render_services_left_section( $content ) { 
        $options = tp_philosophy_pro_get_theme_options(); // get theme options
        $heading_box_layout = ( true == $options['enable_heading_box_layout'] ) ? 'add-gray-border' : '';
    ?>
        <div class="column-wrapper">
            <div class="services-wrapper">
                <header class="entry-header <?php echo esc_attr( $heading_box_layout ); ?>">
                <?php 
                    if( !empty( $content['title'] ) ){
                        echo '<h2 class="entry-title color-white">'. esc_html(  $content['title'] ) .'</h2>';
                    }

                    if( !empty( $content['subtitle'] ) ){
                        echo '<h3 class="sub-title">'. esc_html(  $content['subtitle'] ) .'</h3>';
                    }
                ?>
                </header><!--.entry-header-->
                <div class="entry-content">
                    <?php
                        if( !empty( $content['description'] ) ){
                            echo  '<p>'. esc_html( $content['description'] ) .'</p>';
                        } 
                    ?>

                    <?php if ( ! empty( $content['read_more_text'] ) ) : ?>
                        <a href="<?php echo esc_url( $content['read_more_link'] ); ?>" class="view-more hover-white"><span data-hover="<?php echo esc_attr( $content['read_more_text'] ); ?>"><?php echo esc_html( $content['read_more_text'] ); ?></span></a>
                    <?php endif; ?>

                </div><!--.entry-content-->
            </div><!-- .service-wrapper -->
        </div><!-- .column-wrapper -->
    <?php 
    }
endif;

if ( ! function_exists( 'tp_philosophy_pro_get_services_right_content' ) ) : 
    /**
     * Add services section right content
     *
     * @since 1.0
     */
    function tp_philosophy_pro_get_services_right_content() {
        // Get services right section details
        $section_details = array();
        $section_details = apply_filters( 'tp_philosophy_pro_filter_services_right_details', $section_details );
        if ( empty( $section_details ) ) {
          return;
        }

        // Render services right section now.
        tp_philosophy_pro_render_services_right_section( $section_details );
    }
endif;
add_action( 'tp_philosophy_pro_services_left_content', 'tp_philosophy_pro_get_services_right_content', 10 );

if ( ! function_exists( 'tp_philosophy_pro_get_services_right_section_details' ) ) :
  /**
   * Services section right details.
   *
   * @since 1.0
   * @param array $input services right section details.
   */
  function tp_philosophy_pro_get_services_right_section_details( $input ) {
    $options = tp_philosophy_pro_get_theme_options();
    $services_background_image = !empty( $options['services_background_image'] ) ? $options['services_background_image'] : '';

    // services right section content type
    $services_right_content_type     = $options['services_right_content_type'];

    $content = array();
    switch ( $services_right_content_type ) {
        case 'demo':
            $content['services_background'] = get_template_directory_uri() . '/assets/uploads/services-bg.png';
            $icon_lists = array( 'fa-lightbulb-o', 'fa-trophy', 'fa-volume-up', 'fa-camera' );
            $title_lists = array( 
                    esc_html__( 'DISCOVER & STRATEGY', 'tp-philosophy-pro' ),
                    esc_html__( 'BRANDING', 'tp-philosophy-pro' ), 
                    esc_html__( 'MULTI-MEDIA', 'tp-philosophy-pro' ), 
                    esc_html__( 'PHOTOGRAPHY', 'tp-philosophy-pro' ) 
            );  
            for( $i=1; $i<=4; $i++ ){
                $content['featured_services'][$i]['title'] = $title_lists[$i-1];
                $content['featured_services'][$i]['icon'] = $icon_lists[$i-1];
                $content['featured_services'][$i]['description'] = esc_html__( 'Proin ultricies commodo mi, vel dapibus massa vulputate vitae. Vivamus lectus odio, dictum eget leo a, elementum scelerisque orci. Nullam mauris ante, gravida ac nunc sed.', 'tp-philosophy-pro' );

            }
        break;

        case 'posts':
            $service_posts_ids      = array(); // set empty array of posts id
            $service_posts_icon     = array();
            for( $i=1; $i<=4; $i++ ){
                if( !empty( $options['featured_service_post_id_'. $i ] ) ){
                    $service_post_id    = ! empty ( $options['featured_service_post_id_' . $i] ) ? absint( $options['featured_service_post_id_' . $i] ) : '';
                    $service_posts_ids  = array_merge( $service_posts_ids, array( $service_post_id ) );

                    $service_post_icon = ! empty ( $options['featured_service_icon_' . $i] ) ? $options['featured_service_icon_' . $i] : '';

                    $service_posts_icon = array_merge( $service_posts_icon, array( $service_post_icon ) );
                }
            }

            $content['services_background'] = $services_background_image;
            $content['featured_services'] = array(); // Initialize a empty array for featured services

            // Bail if no valid posts are selected.
            if ( empty( $service_posts_ids ) ) {
                return $input;
            }
            $services_args = array(
                'post_type'      => 'post',
                'post__in'       => $service_posts_ids,
                'orderby'        => 'post__in',
                'posts_per_page' => 4,
            );

            $services_post = get_posts( $services_args );
            $j = 1;
            foreach ( $services_post as $service_post ) {
                $content['featured_services'][$j]['title'] = get_the_title( $service_post->ID );
                $content['featured_services'][$j]['icon']  =  $service_posts_icon[$j-1];
                $content['featured_services'][$j]['description'] = tp_philosophy_pro_trim_content( 15, $service_post );
                $j++;
            }
        break;

        case 'custom':
            $content['services_background'] = $services_background_image; 

            $content['featured_services'] = array(); // Initialize a empty array for featured services
            
            for( $i=1; $i<=4; $i++ ){
                $service_title = !empty( $options['featured_service_title_'. $i ] ) ? $options['featured_service_title_'. $i ] : '';
                $service_icon = !empty( $options['featured_service_icon_'. $i ] ) ? $options['featured_service_icon_'. $i ] : '';
                $service_description = !empty( $options['featured_service_description_'. $i ] ) ? $options['featured_service_description_'. $i ] : '';

                $content['featured_services'][$i]['title'] = $service_title;
                $content['featured_services'][$i]['icon'] = $service_icon;
                $content['featured_services'][$i]['description'] = $service_description;
            }
        break;

        default:
        break;
    }
                                                                                                               
    if ( !empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// services right section content details.
add_filter( 'tp_philosophy_pro_filter_services_right_details', 'tp_philosophy_pro_get_services_right_section_details' );

if ( ! function_exists( 'tp_philosophy_pro_render_services_right_section' ) ) :
  /**
   * Start services right section
   *
   * @return string services right section content
   * @since 1.0
   *
   */
   function tp_philosophy_pro_render_services_right_section( $right_content ) {
        $services_lists =  $right_content['featured_services'];
        if( !empty( $services_lists ) ) : 
    ?>
        <div class="column-wrapper">
            <?php 
                if( !empty( $right_content['services_background'] ) ){
                    $services_background_inline_css = "style='background-image: url(". esc_url( $right_content['services_background'] ) .");'";
                }else{
                    $services_background_inline_css = '';
                }
            ?>
            <div class="our-services col-2 clear" <?php echo $services_background_inline_css; ?>>
                <?php foreach ($services_lists as $service ) : ?>
                    <div class="column-wrapper" >
                        <div class="services-container">
                        <?php 
                            if( !empty( $service['icon'] ) ){
                                echo    '<div class="icon-container">
                                            <i class="fa '. esc_attr( $service['icon'] ) .'"></i>
                                        </div><!--.icon-container-->';
                            }

                            if( !empty( $service['title'] ) ){
                                echo '<h4>'. esc_html( $service['title'] ) .'</h4>';
                            }

                            if( !empty( $service['description'] ) ){
                                echo '<p>'. esc_html( $service['description'] ) .'</p>';
                            }
                        ?>
                        </div><!--.services-container-->
                    </div><!--.column-wrapper-->
                <?php endforeach; ?>

            </div><!--.bg-white-->
        <?php endif; ?>
        </div><!--.column-wrapper-->
    <?php 
    }
endif;